@@ -1,6 +1,8 @@
 """OmniSciDB backend."""
 from __future__ import annotations
 
+import warnings
+from importlib.metadata import PackageNotFoundError, version
 from typing import Optional, Union
 
 import ibis.common.exceptions as com
@@ -23,12 +25,18 @@ from .client import OmniSciDBDataType, OmniSciDBTable, get_cursor_class
 from .compiler import OmniSciDBCompiler
 from .udf import OmniSciDBUDF
 
+try:
+    __version__ = version("ibis_omniscidb")
+except PackageNotFoundError:
+    __version__ = ""
+
+
 try:
     from cudf import DataFrame as GPUDataFrame
 except (ImportError, OSError):
     GPUDataFrame = None
 
-__all__ = ('Backend',)
+__all__ = ('Backend', "__version__")
 
 
 class Backend(BaseSQLBackend):
@@ -108,14 +116,16 @@ class Backend(BaseSQLBackend):
 
         if session_id:
             kwargs = {'sessionid': session_id}
+        elif uri is not None:
+            kwargs = {}
         elif (
             user is not None and password is not None and database is not None
         ):
             kwargs = {'user': user, 'password': password, 'dbname': database}
         else:
             raise ValueError(
-                'If `session_id` is not provided, then `user`, '
-                '`password` and `database` must be provided.'
+                'If `session_id` is not provided, then the connection `uri` '
+                'or all `user`, `password` and `database` must be provided.'
             )
 
         new_backend.con = pyomnisci.connect(
@@ -771,3 +781,34 @@ class Backend(BaseSQLBackend):
             Version of the backend library.
         """
         return pyomnisci.__version__
+
+
+def connect(
+    uri: Optional[str] = None,
+    user: Optional[str] = None,
+    password: Optional[str] = None,
+    host: Optional[str] = None,
+    port: Optional[int] = 6274,
+    database: Optional[str] = None,
+    protocol: str = 'binary',
+    session_id: Optional[str] = None,
+    ipc: Optional[bool] = None,
+    gpu_device: Optional[int] = None,
+):
+    warnings.warn(
+        '`ibis_omniscidb.connect(...)` is deprecated and will be removed in '
+        'a future version. Use `ibis.omniscidb.connect(...)` instead.',
+        FutureWarning,
+    )
+    return Backend().connect(
+        uri,
+        user,
+        password,
+        host,
+        port,
+        database,
+        protocol,
+        session_id,
+        ipc,
+        gpu_device,
+    )
